@@ -49,6 +49,9 @@ import org.objectweb.asm.tree.VarInsnNode;
  */
 public class Frame<V extends Value> {
 
+  /** The maximum size of the operand stack of any method. */
+  private static final int MAX_STACK_SIZE = 65536;
+
   /**
    * The expected return type of the analyzed method, or {@literal null} if the method returns void.
    */
@@ -57,26 +60,43 @@ public class Frame<V extends Value> {
   /**
    * The local variables and the operand stack of this frame. The first {@link #numLocals} elements
    * correspond to the local variables. The following {@link #numStack} elements correspond to the
-   * operand stack.
+   * operand stack. Long and double values are represented with two elements in the local variables
+   * section, and with one element in the operand stack section.
    */
   private V[] values;
 
-  /** The number of local variables of this frame. */
+  /**
+   * The number of local variables of this frame. Long and double values are represented with two
+   * elements.
+   */
   private int numLocals;
 
-  /** The number of elements in the operand stack. */
+  /**
+   * The number of elements in the operand stack. Long and double values are represented with a
+   * single element.
+   */
   private int numStack;
 
+  /**
+   * The maximum number of elements in the operand stack. Long and double values are represented
+   * with a single element.
+   */
+  private int maxStack;
+
   /**
    * Constructs a new frame with the given size.
    *
-   * @param numLocals the maximum number of local variables of the frame.
-   * @param numStack the maximum stack size of the frame.
+   * @param numLocals the number of local variables of the frame. Long and double values are
+   *     represented with two elements.
+   * @param maxStack the maximum number of elements in the operand stack, or -1 if there is no
+   *     maximum value. Long and double values are represented with a single element.
    */
   @SuppressWarnings("unchecked")
-  public Frame(final int numLocals, final int numStack) {
-    this.values = (V[]) new Value[numLocals + numStack];
+  public Frame(final int numLocals, final int maxStack) {
+    this.values = (V[]) new Value[numLocals + (maxStack >= 0 ? maxStack : 4)];
     this.numLocals = numLocals;
+    this.numStack = 0;
+    this.maxStack = maxStack >= 0 ? maxStack : MAX_STACK_SIZE;
   }
 
   /**
@@ -97,8 +117,14 @@ public class Frame<V extends Value> {
    */
   public Frame<V> init(final Frame<? extends V> frame) {
     returnValue = frame.returnValue;
-    System.arraycopy(frame.values, 0, values, 0, values.length);
+    if (values.length < frame.values.length) {
+      values = frame.values.clone();
+    } else {
+      System.arraycopy(frame.values, 0, values, 0, frame.values.length);
+    }
+    numLocals = frame.numLocals;
     numStack = frame.numStack;
+    maxStack = frame.maxStack;
     return this;
   }
 
@@ -135,7 +161,8 @@ public class Frame<V extends Value> {
   }
 
   /**
-   * Returns the maximum number of local variables of this frame.
+   * Returns the maximum number of local variables of this frame. Long and double values are
+   * represented with two variables.
    *
    * @return the maximum number of local variables of this frame.
    */
@@ -144,16 +171,18 @@ public class Frame<V extends Value> {
   }
 
   /**
-   * Returns the maximum stack size of this frame.
+   * Returns the maximum number of elements in the operand stack of this frame. Long and double
+   * values are represented with a single element.
    *
-   * @return the maximum stack size of this frame.
+   * @return the maximum number of elements in the operand stack of this frame.
    */
   public int getMaxStackSize() {
-    return values.length - numLocals;
+    return maxStack;
   }
 
   /**
-   * Returns the value of the given local variable.
+   * Returns the value of the given local variable. Long and double values are represented with two
+   * variables.
    *
    * @param index a local variable index.
    * @return the value of the given local variable.
@@ -167,7 +196,8 @@ public class Frame<V extends Value> {
   }
 
   /**
-   * Sets the value of the given local variable.
+   * Sets the value of the given local variable. Long and double values are represented with two
+   * variables.
    *
    * @param index a local variable index.
    * @param value the new value of this local variable.
@@ -181,10 +211,10 @@ public class Frame<V extends Value> {
   }
 
   /**
-   * Returns the number of values in the operand stack of this frame. Long and double values are
-   * treated as single values.
+   * Returns the number of elements in the operand stack of this frame. Long and double values are
+   * represented with a single element.
    *
-   * @return the number of values in the operand stack of this frame.
+   * @return the number of elements in the operand stack of this frame.
    */
   public int getStackSize() {
     return numStack;
@@ -236,9 +266,15 @@ public class Frame<V extends Value> {
    * @param value the value that must be pushed into the stack.
    * @throws IndexOutOfBoundsException if the operand stack is full.
    */
+  @SuppressWarnings("unchecked")
   public void push(final V value) {
     if (numLocals + numStack >= values.length) {
-      throw new IndexOutOfBoundsException("Insufficient maximum stack size.");
+      if (numLocals + numStack >= maxStack) {
+        throw new IndexOutOfBoundsException("Insufficient maximum stack size.");
+      }
+      V[] oldValues = values;
+      values = (V[]) new Value[2 * values.length];
+      System.arraycopy(oldValues, 0, values, 0, oldValues.length);
     }
     values[numLocals + (numStack++)] = value;
   }
