@@ -114,7 +114,7 @@ public class AnalyzerAdapterTest extends AsmTest {
     } else {
       assertDoesNotThrow(accept);
       Executable newInstance = () -> new ClassFile(classWriter.toByteArray()).newInstance();
-      if (classParameter.isMoreRecentThanCurrentJdk()) {
+      if (classParameter.isNotCompatibleWithCurrentJdk()) {
         assertThrows(UnsupportedClassVersionError.class, newInstance);
       } else {
         assertDoesNotThrow(newInstance);
