@@ -943,9 +943,9 @@ public class CheckClassAdapter extends ClassVisitor {
         mask = 0xFF0000FF;
         break;
       default:
-        throw new AssertionError();
+        break;
     }
-    if ((typeRef & ~mask) != 0) {
+    if (mask == 0 || (typeRef & ~mask) != 0) {
       throw new IllegalArgumentException(
           "Invalid type reference 0x" + Integer.toHexString(typeRef));
     }
@@ -999,8 +999,6 @@ public class CheckClassAdapter extends ClassVisitor {
       // Can't fix PMD warning for 1.5 compatibility.
       try (InputStream inputStream = new FileInputStream(args[0])) { // NOPMD(AvoidFileStream)
         classReader = new ClassReader(inputStream);
-      } catch (IOException ioe) {
-        throw ioe;
       }
     } else {
       classReader = new ClassReader(args[0]);
